@@ -2,7 +2,7 @@
 
    xlog - GTK+ logging program for amateur radio operators
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
-   Copyright (C) 2016 Andy Stewart <kb1oiq@arrl.net>
+   Copyright (C) 2016 - 2021 Andy Stewart <kb1oiq@arrl.net>
 
    This file is part of xlog.
 
@@ -45,6 +45,10 @@
 #include "../data/pixmaps/s8.xpm"
 #include "../data/pixmaps/s9.xpm"
 
+#ifndef FILPATHLEN
+#define FILPATHLEN 100
+#endif
+
 struct rig_id {
 	const gint modelnr;
 	const gchar *modelname;
@@ -173,7 +177,7 @@ start_hamlib (gint rigid, gchar *device, gint debugmode, gint timervalue)
 	if (retcode != RIG_OK)
 	{
 		temp = g_strdup_printf
-			(_("An error occured while opening port %s: %s"),
+			(_("An error occurred while opening port %s: %s"),
 				myrig->state.rigport.pathname, rigerror (retcode));
 		update_statusbar (temp);
 		return FALSE;
@@ -313,8 +317,10 @@ get_powerlevel (void)
 		{
 			status = rig_power2mW (myrig, &programstate.rigpower, val.f, programstate.rigfrequency, programstate.rigmode);
 		}
-		else if (retcode != -RIG_ENAVAIL)
-			hamlib_error (retcode);
+		// If hamlib cannot return a power level, don't cause an error.
+		// The "Power" field in the New QSO pane will simply display UNKNOWN.
+		//		else if (retcode != -RIG_ENAVAIL)
+		//			hamlib_error (retcode);
 	}
 }
 
@@ -400,37 +406,41 @@ get_ptt (void)
 void
 get_smeter (void)
 {
-	gint retcode, strength, spoint, i, smax = 0;
+  gint retcode, spoint, i, smax = 0;
+  value_t strength;
 
-	retcode = rig_get_strength (myrig, RIG_VFO_CURR, &strength);
-	if (retcode == RIG_OK)
-	{
-		if (strength >= 0)
-			spoint = 9;
-		else
-			spoint = (gint) floor ((strength + 54) / 6);
+  retcode = rig_get_level(myrig, RIG_VFO_CURR, RIG_LEVEL_STRENGTH, &strength);
+  
+  // If getting the smeter reading fails, the code will simply
+  // ignore that error.
+  if (retcode != RIG_OK)
+	strength.i = 0;  // pretend S9
+  
+  if (strength.i >= 0)
+	spoint = 9;
+  else
+	spoint = (gint) floor ((strength.i + 54) / 6);
 
-		svalue[programstate.scounter] = spoint;
-		programstate.scounter++;
-		if (programstate.scounter == 3)
-			programstate.scounter = 0;
+  svalue[programstate.scounter] = spoint;
+  programstate.scounter++;
+  if (programstate.scounter == 3)
+	programstate.scounter = 0;
 
-		/* find maximum of s-meter during last 3 measurements */
-		for (i = 0; i < 3; i++)
-			if (svalue[i] > smax)
-				smax = svalue[i];
+  /* find maximum of s-meter during last 3 measurements */
+  for (i = 0; i < 3; i++)
+	if (svalue[i] > smax)
+	  smax = svalue[i];
 
-		if ((preferences.hamlib == 3) || (preferences.hamlib == 4))
-			draw_smeter (smax);
+  if ((preferences.hamlib == 3) || (preferences.hamlib == 4)) {
+	draw_smeter (smax);
+  }
+  
+  if ((programstate.rigmode == RIG_MODE_CW) ||
+	  (programstate.rigmode == RIG_MODE_RTTY))
+	programstate.rigrst = g_strdup_printf ("5%d9", smax);
+  else
+	programstate.rigrst = g_strdup_printf ("5%d", smax);
 
-		if ((programstate.rigmode == RIG_MODE_CW)
-				|| (programstate.rigmode == RIG_MODE_RTTY))
-			programstate.rigrst = g_strdup_printf ("5%d9", smax);
-		else
-			programstate.rigrst = g_strdup_printf ("5%d", smax);
-	}
-	else if (retcode != -RIG_ENAVAIL)
-		hamlib_error (retcode);
 }
 
 /* used by 'click all menu' when not polling */
@@ -622,9 +632,9 @@ GString *convert_frequency (void)
 	GString *digits = g_string_new ("");
 
 	if (preferences.round == 0)
-		g_string_printf (digits, "%Ld", programstate.rigfrequency);
+		g_string_printf (digits, "%lld", programstate.rigfrequency);
 	else
-		g_string_printf (digits, "%Ld", (long long) rint (programstate.rigfrequency /
+		g_string_printf (digits, "%lld", (long long) rint (programstate.rigfrequency /
 			pow (10, preferences.round)));
 	g_string_insert_c (digits, (digits->len) - 6 + preferences.round, '.');
 	g_strstrip (digits->str);
